# vteklib
Library for easy and fast build scientific-style plots

`pip install vteklib`

The main config file is vteklib/vtek_style.mplstyle
You can download it manually and use like:
`import matplotlib.pyplot as plt` & `plt.style.use('...path_to_vtek.mplstyle')`

All other code is a wrapper for easier use a data from excel and csv tables. Maybe some day it'll become a part of web-app.

## Examples
Unlike ohter .mplstyle configs, there's no problem with unicode symbols
![230_real_gas](https://user-images.githubusercontent.com/87110754/172028275-f8a0b6b5-4a20-460e-b3f0-87df00c52735.png)

Linear regression example
![240_1_0](https://user-images.githubusercontent.com/87110754/172028399-99e6d46c-097a-49e0-a958-86193f03b446.png)
